﻿' Copyright (C) 2010 by Crucible-Technologies Ltd.
'
' Permission is hereby granted, free of charge, to any person obtaining a copy
' of this software and associated documentation files (the "Software"), to deal
' in the Software without restriction, including without limitation the rights
' to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
' copies of the Software, and to permit persons to whom the Software is
' furnished to do so, subject to the following conditions:
'
' The above copyright notice and this permission notice shall be included in
' all copies or substantial portions of the Software.
' 
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
' IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
' FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
' AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
' LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
' OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
' THE SOFTWARE.

' CTI Comet USB AutoFind
'   Ver     Date            Notes               Changes by
'   v1.0    24/01/2011      Original release    Ryan Diver

Imports System.Management

Module MainModule

    Sub Main()

        ' Create the dictionary to hold all COMETS.
        Dim result As New Dictionary(Of String, String)

        ' Search for all COMET devices.
        result = findCOM()

        ' Output the result to the console.
        Dim i As Integer
        Dim str As String
        str = ""
        i = 0
        For Each foundPort As KeyValuePair(Of String, String) In result
            If Not (i = 0) Then
                str += ";"
            End If
            str += "COM" + foundPort.Key
            i = i + 1
        Next
        System.Console.Write(str)

        ' Thread sleep (Used for testing in Visual Studios)
        'System.Threading.Thread.Sleep(10000)
    End Sub

    ' Returns a list of COM port numbers for all attached CTI Comet USB devices.
    ' Formatted with a ; between each device.
    Private Function findCOM()
        Dim identPnpPorts As New Dictionary(Of String, String)
        Dim returnSerials As New Dictionary(Of String, String)
        Dim portNameData As String
        Dim comPortNumber As String

        Try
            Dim portSearcher As New ManagementObjectSearcher("\root\CIMV2", "Select Name from Win32_PnPEntity")
            For Each port As System.Management.ManagementObject In portSearcher.Get()

                ' Search all of the PNP entries for devices with COM numbers
                If port("Name").ToString.ToUpper.Contains("(COM") Then
                    portNameData = port("Name").ToString
                    comPortNumber = port("Name").ToString.Substring(port("Name").ToString.IndexOf("(COM") + 4)
                    comPortNumber = comPortNumber.TrimEnd(")"c)
                    identPnpPorts.Add(comPortNumber, portNameData)
                End If
            Next
        Catch ex As Exception
            'Need to handle possible errors
        End Try

        ' Find the device
        For Each foundPort As KeyValuePair(Of String, String) In identPnpPorts
            If (foundPort.Value.Contains("CTI Comet USB COM Port")) Then
                returnSerials.Add(foundPort.Key, foundPort.Value)
            End If
        Next

        Return returnSerials

    End Function
End Module
